import numpy as np
from numpy import pi, sum, abs, conj, swapaxes, sqrt, exp, reshape, log10

def Es(data, *args, **kwargs):
  """
  Signal Energy
  """
  return sum(abs(data)**2, *args, **kwargs)

def H(A):
  """
  Hermitian Transpose of (the last two dimensions) of A
  """
  return conj(swapaxes(A, -2, -1))


def pow2db(input_power):
  """
  Converts input power (linear) to dB
  :param input_power: power to be converted to dB
  :return: dB of input power
  """
  return 10*log10(input_power)

def db2pow(db):
  """
  Converts dB to (linear) power
  :param db: input power in dB
  :return: (linear) power of the input db value
  """
  return 10**(np.asarray(db)/10)

def mag2db(input_magnitude):
  """
  Converts input magnitude (linear) to dB
  :param input_magnitude: (linear) input magnitude to be converted to dB
  :return: dB value of input magnitude
  """
  return 20*log10(abs(input_magnitude))

def db2mag(db):
  """
  Converts dB to (linear) magnitude
  :param db: input magnitude in dB
  :return: corresponding (linear) magnitude
  """
  return 10**(np.asarray(db)/20)